require 'minitest/autorun'
require 'minitest/spec'
require 'fileutils'

describe 'foodfactory' do
  def run_foodfactory(path = nil)
    foodfactory_binary = File.join(File.dirname(__FILE__), '../bin/foodfactory')
    `ruby #{foodfactory_binary} #{path}`
  end

  before do
    @cookbook_file = [*('A'..'Z')].sample(8).join
  end

  it 'dies without a cookbook_name' do
    assert_equal("No cookbook name provided\n", run_foodfactory)
  end
  it 'creates a cookbook' do
    run_foodfactory(@cookbook_file)
    assert File.exist?("#{@cookbook_file}/README.md")
    FileUtils.rm_rf(@cookbook_file)
    assert File.exist?(File.join(Dir.home, '.foodfactory'))
  end
  it 'accepts an arbitrary path' do
    cookbook_path = File.join('/tmp/', @cookbook_file)
    run_foodfactory(cookbook_path)
    assert File.exist?(File.join(cookbook_path, 'README.md'))
    FileUtils.rm_rf(cookbook_path)
    assert File.exist?(File.join(Dir.home, '.foodfactory'))
  end
  it 'accepts arbitrary relative paths' do
    cookbook_path = "./#{@cookbook_file}"
    run_foodfactory(cookbook_path)
    assert File.exist?(File.join(cookbook_path, 'README.md'))
    FileUtils.rm_rf(cookbook_path)
    assert File.exist?(File.join(Dir.home, '.foodfactory'))
  end
  it 'exits if the file already exists' do
    File.write(@cookbook_file, 'foodfactory test file')
    output = run_foodfactory(@cookbook_file)
    assert_equal("Cookbook already exists\n", output)
    File.unlink(@cookbook_file)
  end

end